Built-in columns — django-tables2 1.2.4 documentation

# Built-in columns

For common use-cases the following columns are included:

- `BooleanColumn` – renders boolean values
- `Column` – generic column
- `CheckBoxColumn` – renders checkbox form inputs
- `DateColumn` – date formatting
- `DateTimeColumn` – datetime formatting in the local timezone
- `FileColumn` – renders files as links
- `EmailColumn` – renders `<a href="mailto:...">` tags
- `LinkColumn` – renders `<a href="...">` tags (compose a django url)
- `RelatedLinkColumn` – renders `<a href="...">` tags linking related objects
- `TemplateColumn` – renders template code
- `URLColumn` – renders `<a href="...">` tags (absolute url)